==> tine20-tinebase_2016.11.24.tar.bz2: Addressbook/js/Addressbook-lang-es_MX-debug.js <==
/********************** tine translations of Addressbook**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/Addressbook'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Spanish (Mexico) (http://www.transifex.com/tine20/tine20/language/es_MX/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: es_MX\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Datos de contacto de empresa"

, "Organisation / Unit"
: "Organización / Unidad"

, "Business Address"
: "Dirección de la empresa"

, "Email"
: "Email"

, "Telephone Work"
: "Teléfono de trabajo"

, "Telephone Cellphone"
: "Teléfono celular"

, "Telephone Car"
: "Teléfono del automóvil"

, "Telephone Fax"
: "Teléfono Fax"

, "Telephone Page"
: "Página del teléfono"

, "URL"
: "URL"

, "Role"
: "Cargo"

, "Room"
: "Sala"

, "Assistant"
: "Asistente"

, "Assistant Telephone"
: "Teléfono del asistente"

, "Private Contact Data"
: "Datos de contacto privados"

, "Private Address"
: "Dirección privada"

, "Email Home"
: "Email doméstico"

, "Telephone Home"
: "Teléfono del hogar"

, "Telephone Cellphone Private"
: "Teléfono Celular Privado"

, "Telephone Fax Home"
: "Teléfono Fax Doméstico"

, "URL Home"
: "URL doméstico"

, "Other Data"
: "Otra Información"

, "Birthday"
: "Cumpleaños"

, "Job Title"
: "Nombre del Cargo"

, "Dear Mister"
: ""

, "Dear Miss"
: ""

, "Dear"
: ""

, "Mister"
: ""

, "Misses"
: ""

, "%s's personal addressbook"
: "Libreta de direcciones de %s's"

, "Lists"
: ""

, "List Roles"
: ""

, "manage shared addressbooks"
: "administrar libretas de direcciones compartidas"

, "Create new shared addressbook folders"
: "Crear nuevas libretas de direcciones compartidas"

, "manage shared addressbook favorites"
: "administrar favoritos de libretas de direcciones compartidas"

, "Create or update shared addressbook favorites"
: "Crear o actualizar favoritos de libretas de direcciones compartidas"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list roles in CoreData"
: ""

, "View, create, delete or update list roles in CoreData application"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "CardDAV URL"
: ""

, "Contact, Contacts"
: [
  "Contacto"
 ,"Contactos"

]
, "List Role, , n); gettext("
: [
  ""
 ,""

]
, "Members"
: ""

, "Remove Member"
: ""

, "Map"
: "Mapa"

, "Personal Information"
: "Información Personal"

, "Salutation"
: "Trato"

, "Title"
: "Título"

, "First Name"
: "Nombre"

, "Middle Name"
: "Segundo Nombre"

, "Last Name"
: "Apellidos"

, "Company"
: "Compañía"

, "Unit"
: "Unidad"

, "Suffix"
: "Sufijo"

, "Job Role"
: "Descripción del Cargo"

, "Display Name"
: "Nombre a Mostrar"

, "Contact Information"
: "Información de Contacto"

, "Phone"
: "Teléfono"

, "Mobile"
: "Móvil"

, "Fax"
: "Fax"

, "Phone (private)"
: "Fono (privado)"

, "Mobile (private)"
: "Celular (privado)"

, "Fax (private)"
: "Fax (privado)"

, "E-Mail"
: "E-Mail"

, "E-Mail (private)"
: "E-Mail (privado)"

, "Web"
: "Web"

, "Company Address"
: "Dirección de la Empresa"

, "Street"
: "Calle"

, "Street 2"
: "Dirección 2"

, "Region"
: "Región"

, "Postal Code"
: "Código Postal"

, "City"
: "Ciudad"

, "Country"
: "País"

, "Description"
: "Descripción"

, "Enter description"
: "Escribir descripción"

, "Export as pdf"
: "Exportar como pdf"

, "Parse address"
: ""

, "Paste address"
: ""

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: ""

, "New Contact"
: ""

, "Addressbook, Addressbooks"
: [
  ""
 ,""

]
, "ID"
: ""

, "Name"
: ""

, "Member of List"
: ""

, "Street (Company Address)"
: ""

, "Street 2 (Company Address)"
: ""

, "City (Company Address)"
: ""

, "Region (Company Address)"
: ""

, "Postal Code (Company Address)"
: ""

, "Country (Company Address)"
: ""

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: ""

, "Street 2 (Private Address)"
: ""

, "City (Private Address)"
: ""

, "Region (Private Address)"
: ""

, "Postal Code (Private Address)"
: ""

, "Country (Private Address)"
: ""

, "Company Communication"
: ""

, "Private Communication"
: ""

, "Web (private)"
: ""

, "Contacts"
: "Contactos"

, "Addressbooks"
: ""

, "User Account"
: "Cuenta de Usuario"

, "Quick Search"
: ""

, "Type"
: "Tipo"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Fecha de Creación"

, "Created By"
: ""

, "List, Lists"
: [
  ""
 ,""

]
, "Quick search"
: ""

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Select list"
: ""

, "List type"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "List Information"
: ""

, "{0} must be given"
: ""

, "Company address"
: ""

, "Private address"
: ""

, "Select contact"
: "Seleccionar contacto"

, "Private"
: "Privado"

, "Info"
: "Información"

, "Insecure link"
: ""

, "Please review this link in edit dialog."
: ""

, "Export {0}, Export {0}"
: [
  ""
 ,""

]
, "Export as PDF"
: "Exportar como PDF"

, "Export as CSV"
: "Exportar como CSV"

, "Export as ODS"
: ""

, "Export as XLS"
: ""

, "Export as DOC"
: ""

, "Export as ..."
: ""

, "Import contacts"
: ""

, "Contact of a user account"
: ""

, "No name"
: ""

, "Tags"
: "Etiquetas"

, "Full Name"
: "Nombre Completo"

, "Postalcode"
: "Código Postal"

, "Street (private)"
: "Calle (privado)"

, "City (private)"
: "Ciudad (privado)"

, "Region (private)"
: "Región (privado)"

, "Postalcode (private)"
: "Código Postal (privado)"

, "Country (private)"
: "País (privado)"

, "Car phone"
: "Teléfono del Automóvil"

, "Pager"
: "Buscapersonas"

, "Email (private)"
: "Email (privado)"

, "URL (private)"
: "URL (privado)"

, "Note"
: "Nota"

, "Timezone"
: "Zona Horaria"

, "Geo"
: "Geo"

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Uploaded new contact image."
: ""

, "All contacts"
: ""

, "Default Addressbook"
: "Libreta de Contactos Predefinida"

, "The default addressbook for new contacts"
: "La libreta de dirección predefinida para nuevos contactos"

, "Default Favorite"
: ""

, "The default favorite which is loaded on addressbook startup"
: ""

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "All Contacts"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Calendar Application."
: ""

, "Calendar Split View"
: ""

, "Split day and week views by attendee)"
: ""

, "Contact duplicate check fields"
: "Revisar campos por contactos duplicados"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Estos campos son revisados cuando un nuevo contacto es creado. Si un registro con la misma información en los campos es identificado, se produce una excepción por duplicidad."

, "Contact salutations available"
: "Saludos de contacto disponibles"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Posibles saludos de contacto. Por favor toma en cuenta que valores adicionales podrían impactar otros  sistemas de Libretas de Direcciones al ser exportados o sincronizados."

, "Mr"
: "Sr"

, "Ms"
: "Sra"

, "Parsing rules for addresses"
: "Analizando reglas para direcciones"

, "Path to a XML file with address parsing rules."
: "Ruta hacia el archivo XML con reglas de dirección de análisis."

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: ""

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: ""

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Importar contacto desde libreta de direcciones de Google"

, "Contact CSV import from mac address book"
: "Importar CSV de contacto de libreta de direcciones mac"

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Importar VCARD de contacto"

, "Internal Contacts"
: "Contactos Internos"

, "All contacts I have read grants for"
: ""

, "My company"
: ""

, "All coworkers in my company"
: ""

, "My contacts"
: ""

, "All contacts in my Addressbooks"
: ""

, "Last modified by me"
: ""

, "All contacts that I have last modified"
: ""

, "Contact"
: "Contacto"

, "List Role"
: ""

, "Addressbook"
: ""

, "List"
: ""

, "Email Address"
: ""

, "Export {0}"
: ""

}));

==> tine20-tinebase_2019.11.25.tar.bz2: Addressbook/js/Addressbook-lang-es_MX-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (Mexico) (http://www.transifex.com/tine20/tine20/language/es_MX/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: es_MX\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Datos de contacto de empresa"

, "Organisation / Unit"
: "Organización / Unidad"

, "Business Address"
: "Dirección de la empresa"

, "Email"
: "Email"

, "Telephone Work"
: "Teléfono de trabajo"

, "Telephone Cellphone"
: "Teléfono celular"

, "Telephone Car"
: "Teléfono del automóvil"

, "Telephone Fax"
: "Teléfono Fax"

, "Telephone Page"
: "Página del teléfono"

, "URL"
: "URL"

, "Role"
: "Cargo"

, "Room"
: "Sala"

, "Assistant"
: "Asistente"

, "Assistant Telephone"
: "Teléfono del asistente"

, "Private Contact Data"
: "Datos de contacto privados"

, "Private Address"
: "Dirección privada"

, "Email Home"
: "Email doméstico"

, "Telephone Home"
: "Teléfono del hogar"

, "Telephone Cellphone Private"
: "Teléfono Celular Privado"

, "Telephone Fax Home"
: "Teléfono Fax Doméstico"

, "URL Home"
: "URL doméstico"

, "Other Data"
: "Otra Información"

, "Birthday"
: "Cumpleaños"

, "Job Title"
: "Nombre del Cargo"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  ""
 ,""

]
, "Percent"
: ""

, "Description"
: "Descripción"

, "Members"
: ""

, "Type"
: "Tipo"

, "List type"
: ""

, "Addressbook, Addressbooks"
: [
  ""
 ,""

]
, "Contact, Contacts"
: [
  "Contacto"
 ,"Contactos"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "País"

, "City"
: "Ciudad"

, "Postalcode"
: "Código Postal"

, "Region"
: "Región"

, "Street"
: "Calle"

, "Street 2"
: "Dirección 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "País (privado)"

, "City (private)"
: "Ciudad (privado)"

, "Postalcode (private)"
: "Código Postal (privado)"

, "Region (private)"
: "Región (privado)"

, "Street (private)"
: "Calle (privado)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "Email (privado)"

, "Free/Busy URI"
: ""

, "Geo"
: "Geo"

, "Groups"
: ""

, "Industry, Industries"
: [
  ""
 ,""

]
, "Note"
: "Nota"

, "Last Name"
: "Apellidos"

, "Display Name"
: "Nombre a Mostrar"

, "Full Name"
: "Nombre Completo"

, "First Name"
: "Nombre"

, "Middle Name"
: "Segundo Nombre"

, "Title"
: "Título"

, "Suffix"
: "Sufijo"

, "Company"
: "Compañía"

, "Unit"
: "Unidad"

, "Paths"
: ""

, "Preferred Address"
: ""

, "Job Role"
: "Descripción del Cargo"

, "Salutation"
: "Trato"

, "syncBackendIds"
: ""

, "Car phone"
: "Teléfono del Automóvil"

, "Mobile"
: "Móvil"

, "Mobile (private)"
: "Celular (privado)"

, "Fax"
: "Fax"

, "Fax (private)"
: "Fax (privado)"

, "Phone (private)"
: "Fono (privado)"

, "Pager"
: "Buscapersonas"

, "Phone"
: "Teléfono"

, "Timezone"
: "Zona Horaria"

, "Web"
: "Web"

, "URL (private)"
: "URL (privado)"

, "Label"
: ""

, "Lists"
: ""

, "Select list"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Contact Information"
: "Información de Contacto"

, "Company Address"
: "Dirección de la Empresa"

, "New Contact"
: ""

, "ID"
: ""

, "Name"
: ""

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Import contacts"
: ""

, "Contact of a user account"
: ""

, "No name"
: ""

, "Business"
: ""

, "Private"
: "Privado"

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Etiquetas"

, "List Roles"
: ""

, "Street (Company Address)"
: ""

, "Street 2 (Company Address)"
: ""

, "City (Company Address)"
: ""

, "Region (Company Address)"
: ""

, "Postal Code (Company Address)"
: ""

, "Country (Company Address)"
: ""

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: ""

, "Street 2 (Private Address)"
: ""

, "City (Private Address)"
: ""

, "Region (Private Address)"
: ""

, "Postal Code (Private Address)"
: ""

, "Country (Private Address)"
: ""

, "Company Communication"
: ""

, "Private Communication"
: ""

, "E-Mail"
: "E-Mail"

, "E-Mail (private)"
: "E-Mail (privado)"

, "Web (private)"
: ""

, "Contacts"
: "Contactos"

, "Addressbooks"
: ""

, "User Account"
: "Cuenta de Usuario"

, "Quick Search"
: ""

, "Postal Code"
: "Código Postal"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Fecha de Creación"

, "Created By"
: ""

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "List Functions"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "List Information"
: ""

, "Enter description"
: "Escribir descripción"

, "{0} must be given"
: ""

, "Member of List"
: ""

, "Map"
: "Mapa"

, "Company address"
: ""

, "Private address"
: ""

, "CardDAV URL"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Personal Information"
: "Información Personal"

, "Parse address"
: ""

, "Print contact"
: ""

, "Paste address"
: ""

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: ""

, "Remove Member"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "All contacts"
: ""

, "Default Addressbook"
: "Libreta de Contactos Predefinida"

, "The default addressbook for new contacts"
: "La libreta de dirección predefinida para nuevos contactos"

, "Default Favorite"
: ""

, "The default favorite which is loaded on addressbook startup"
: ""

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: "Revisar campos por contactos duplicados"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Estos campos son revisados cuando un nuevo contacto es creado. Si un registro con la misma información en los campos es identificado, se produce una excepción por duplicidad."

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Saludos de contacto disponibles"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Posibles saludos de contacto. Por favor toma en cuenta que valores adicionales podrían impactar otros  sistemas de Libretas de Direcciones al ser exportados o sincronizados."

, "Mr"
: "Sr"

, "Ms"
: "Sra"

, "Parsing rules for addresses"
: "Analizando reglas para direcciones"

, "Path to a XML file with address parsing rules."
: "Ruta hacia el archivo XML con reglas de dirección de análisis."

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Importar VCARD de contacto"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: ""

, "Contact CSV import from mac address book"
: "Importar CSV de contacto de libreta de direcciones mac"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Importar contacto desde libreta de direcciones de Google"

, "manage shared addressbooks"
: "administrar libretas de direcciones compartidas"

, "Create new shared addressbook folders"
: "Crear nuevas libretas de direcciones compartidas"

, "manage shared addressbook favorites"
: "administrar favoritos de libretas de direcciones compartidas"

, "Create or update shared addressbook favorites"
: "Crear o actualizar favoritos de libretas de direcciones compartidas"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "%s's personal addressbook"
: "Libreta de direcciones de %s's"

, "All contacts I have read grants for"
: ""

, "My company"
: ""

, "All coworkers in my company"
: ""

, "My contacts"
: ""

, "All contacts in my Addressbooks"
: ""

, "Last modified by me"
: ""

, "All contacts that I have last modified"
: ""

, "Internal Contacts"
: "Contactos Internos"
, ""
: "Project-Id-Version: Tine 2.0 - GDPR\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: Spanish\nX-Poedit-Country: MEXICO\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "Data provenances"
: ""

, "Data intended purposes"
: ""

, "Show expired"
: ""

, "Data Provenance"
: ""

, "Reason for Editing"
: ""

, "Please enter the reason for editing this data"
: ""

, "Please Confirm the Data Provenance"
: ""

, "GDPR"
: ""

, "Must not be contacted"
: ""

, "This Contact withdrawed usage of his data for any purpose."
: ""

, "Blacklist"
: ""

, "GDPR Intended Purpose"
: ""

, "GDPR Blacklisted"
: ""

, "GDPR Data Provenance"
: ""

, "GDPR Data Editing Reason"
: ""

, "Data provenance for ADB contacts mandatory"
: ""

, "Whether the data provenance for ADB contacts is mandatory, not mandatory or empty provenances will be set to a default"
: ""

, "yes"
: ""

, "no"
: ""

, "default"
: ""

, "Default data provenance for ADB contacts"
: ""

, "Data intended purpose, Data intended purposes"
: [
  ""
 ,""

]
, "Agreement date"
: ""

, "Agreement comment"
: ""

, "Withdraw date"
: ""

, "Withdraw comment"
: ""

, "Data provenance, Data provenances"
: [
  ""
 ,""

]
, "Expiration"
: ""

, "Manage data provenances in CoreData"
: ""

, "View, create, delete or update data provenances in CoreData application"
: ""

, "Manage data intended purposes in CoreData"
: ""

, "View, create, delete or update data intended purposes in CoreData application"
: ""

, "List"
: ""

, "Addressbook"
: ""

, "Contact"
: "Contacto"

, "Industry"
: ""

, "Structure"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

, "Data intended purpose"
: ""

, "Data provenance"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
